@@ -1,5 +1,3 @@
-library(spiro)
-
 file <- spiro_example("zan_gxt")
 
 p1 <- set_protocol(
@@ -25,8 +23,8 @@ dtf2 <- data.frame(
 )
 
 test_that("protocol guessing works", {
-  expect_s3_class(get_protocol(spiro_import(file)), "data.frame")
-  expect_snapshot_output(get_protocol(spiro_import(file)))
+  expect_s3_class(get_protocol(spiro_raw(file)), "data.frame")
+  expect_snapshot_output(get_protocol(spiro_raw(file)))
 })
 
 test_that("protocol is attributed in spiro()", {
