@@ -1,5 +1,3 @@
-library(spiro)
-
 file <- spiro_example("zan_ramp")
 
 test_that("spiro returns correct class", {
@@ -25,5 +23,5 @@ test_that("heart rate import works within spiro()", {
 })
 
 test_that("spiro() returnes a warning for non breath-by-breath data", {
-  expect_warning(spiro(spiro_example("cosmed_test.xlsx")))
+  expect_warning(spiro(test_path("testdata/cosmed.xlsx")))
 })
